@@ -1,9 +1,9 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require_relative 'wrapper'
+require_relative "wrapper"
 
 module Protocol
 	module HTTP
@@ -24,25 +24,20 @@ module Protocol
 					@callback = callback
 				end
 				
-				def finish
-					if @body
-						result = super
-						
-						@callback.call
-						
-						@body = nil
-						
-						return result
-					end
+				def rewindable?
+					false
+				end
+				
+				def rewind
+					false
 				end
 				
 				def close(error = nil)
-					if @body
-						super
-						
-						@callback.call(error)
-						
-						@body = nil
+					super.tap do
+						if @callback
+							@callback.call(error)
+							@callback = nil
+						end
 					end
 				end
 			end
