@@ -1,9 +1,9 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require_relative 'readable'
+require_relative "readable"
 
 module Protocol
 	module HTTP
@@ -18,6 +18,7 @@ module Protocol
 				
 				def initialize(file, range = nil, size: file.size, block_size: BLOCK_SIZE)
 					@file = file
+					@range = range
 					
 					@block_size = block_size
 					
@@ -26,6 +27,7 @@ module Protocol
 						@offset = range.min
 						@length = @remaining = range.size
 					else
+						@file.seek(0)
 						@offset = 0
 						@length = @remaining = size
 					end
@@ -51,13 +53,17 @@ module Protocol
 					true
 				end
 				
+				def buffered
+					self.class.new(@file.dup, @range, block_size: @block_size)
+				end
+				
 				def rewind
 					@file.seek(@offset)
 					@remaining = @length
 				end
 				
-				def stream?
-					false
+				def rewindable?
+					true
 				end
 				
 				def read
@@ -72,6 +78,16 @@ module Protocol
 					end
 				end
 				
+				# def stream?
+				# 	true
+				# end
+				
+				# def call(stream)
+				# 	IO.copy_stream(@file, stream, @remaining)
+				# ensure
+				# 	stream.close
+				# end
+				
 				def join
 					return "" if @remaining == 0
 					
