@@ -1,16 +1,26 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require_relative 'wrapper'
-require_relative 'buffered'
+require_relative "wrapper"
+require_relative "buffered"
 
 module Protocol
 	module HTTP
 		module Body
 			# A body which buffers all it's contents as it is `#read`.
 			class Rewindable < Wrapper
+				def self.wrap(message)
+					if body = message.body
+						if body.rewindable?
+							body
+						else
+							message.body = self.new(body)
+						end
+					end
+				end
+				
 				def initialize(body)
 					super(body)
 					
@@ -26,15 +36,13 @@ module Protocol
 					(@index < @chunks.size) || super
 				end
 				
-				# A rewindable body wraps some other body. Convert it to a buffered body 
+				# A rewindable body wraps some other body. Convert it to a buffered body. The buffered body will share the same chunks as the rewindable body.
+				#
+				# @returns [Buffered] the buffered body. 
 				def buffered
 					Buffered.new(@chunks)
 				end
 				
-				def stream?
-					false
-				end
-				
 				def read
 					if @index < @chunks.size
 						chunk = @chunks[@index]
@@ -54,6 +62,10 @@ module Protocol
 					@index = 0
 				end
 				
+				def rewindable?
+					true
+				end
+				
 				def inspect
 					"\#<#{self.class} #{@index}/#{@chunks.size} chunks read>"
 				end
