@@ -1,15 +1,19 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require_relative 'readable'
+require_relative "readable"
 
 module Protocol
 	module HTTP
 		module Body
 			# Wrapping body instance. Typically you'd override `#read`.
 			class Wrapper < Readable
+				# Wrap the body of the given message in a new instance of this class.
+				#
+				# @parameter message [Request | Response] the message to wrap.
+				# @returns [Wrapper | nil] the wrapped body or nil if the body was nil.
 				def self.wrap(message)
 					if body = message.body
 						message.body = self.new(body)
@@ -23,15 +27,11 @@ module Protocol
 				# The wrapped body.
 				attr :body
 				
-				# Buffer any remaining body.
-				def finish
-					@body.finish
-				end
-				
 				def close(error = nil)
 					@body.close(error)
 					
-					super
+					# It's a no-op:
+					# super
 				end
 				
 				def empty?
@@ -42,6 +42,18 @@ module Protocol
 					@body.ready?
 				end
 				
+				def buffered
+					@body.buffered
+				end
+				
+				def rewind
+					@body.rewind
+				end
+				
+				def rewindable?
+					@body.rewindable?
+				end
+				
 				def length
 					@body.length
 				end
@@ -51,17 +63,24 @@ module Protocol
 					@body.read
 				end
 				
+				def discard
+					@body.discard
+				end
+				
+				def as_json(...)
+					{
+						class: self.class.name,
+						body: @body&.as_json
+					}
+				end
+				
+				def to_json(...)
+					as_json.to_json(...)
+				end
+				
 				def inspect
 					@body.inspect
 				end
-				
-				def stream?
-					@body.stream?
-				end
-				
-				def call(stream)
-					@body.call(stream)
-				end
 			end
 		end
 	end
