@@ -1,9 +1,8 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
-
-require 'base64'
+# Copyright, 2019-2024, by Samuel Williams.
+# Copyright, 2024, by Earlopain.
 
 module Protocol
 	module HTTP
@@ -21,10 +20,10 @@ module Protocol
 				end
 				
 				def self.basic(username, password)
-					encoded = "#{username}:#{password}"
+					strict_base64_encoded = ["#{username}:#{password}"].pack("m0")
 					
 					self.new(
-						"Basic #{Base64.strict_encode64(encoded)}"
+						"Basic #{strict_base64_encoded}"
 					)
 				end
 			end
