@@ -1,17 +1,18 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
+# Copyright, 2024, by Thomas Morgan.
 
-require_relative 'split'
+require_relative "split"
 
 module Protocol
 	module HTTP
 		module Header
 			class Connection < Split
-				KEEP_ALIVE = 'keep-alive'
-				CLOSE = 'close'
-				UPGRADE = 'upgrade'
+				KEEP_ALIVE = "keep-alive"
+				CLOSE = "close"
+				UPGRADE = "upgrade"
 				
 				def initialize(value = nil)
 					super(value&.downcase)
@@ -22,7 +23,7 @@ module Protocol
 				end
 				
 				def keep_alive?
-					self.include?(KEEP_ALIVE)
+					self.include?(KEEP_ALIVE) && !close?
 				end
 				
 				def close?
