@@ -1,9 +1,9 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2023, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require_relative '../middleware'
+require_relative "../middleware"
 
 module Protocol
 	module HTTP
@@ -30,7 +30,13 @@ module Protocol
 			def self.build(&block)
 				builder = Builder.new
 				
-				builder.instance_eval(&block)
+				if block_given?
+					if block.arity == 0
+						builder.instance_exec(&block)
+					else
+						yield builder
+					end
+				end
 				
 				return builder.to_app
 			end
